@@ -4,6 +4,7 @@ from .packages import WGCNA
 from .packages import philr
 from .packages import edgeR
 from .packages import metagenomeSeq
+from .packages import propr
 
-__all__ = ["dynamicTreeCut", "WGCNA", "philr", "edgeR", "metagenomeSeq" ,"R_package_retrieve", "R_packages", "pandas_to_rpy2", "rpy2_to_pandas"]
+__all__ = ["dynamicTreeCut", "WGCNA", "philr", "edgeR", "metagenomeSeq" ,"propr", "R_package_retrieve", "R_packages", "pandas_to_rpy2", "rpy2_to_pandas"]
 __all__ = sorted(__all__)
