@@ -24,7 +24,7 @@ try:
 except ImportError:
     from rpy2.rinterface_lib.embedded import RRuntimeError
 from rpy2.robjects import pandas2ri
-pandas2ri.activate()
+# pandas2ri.activate()
 R = ro.r
 NULL = ri.NULL
 #rinterface.set_writeconsole_regular(None)
@@ -65,5 +65,7 @@ wgcna = R_package_retrieve("WGCNA")
 
 def pickSoftThreshold_fromSimilarity(df_adj, query_powers):
     # Run pickSoftThreshold.fromSimilarity
-    rDF_scalefreetopology = wgcna.pickSoftThreshold_fromSimilarity(R["as.matrix"](pandas_to_rpy2(df_adj)), powerVector = query_powers, verbose=0, moreNetworkConcepts=True)[1]
+    query_powers = ro.FloatVector(list(query_powers))
+    r_adj = pandas_to_rpy2(df_adj)
+    rDF_scalefreetopology = wgcna.pickSoftThreshold_fromSimilarity(R["as.matrix"](r_adj), powerVector = query_powers, verbose=0, moreNetworkConcepts=True)[1]
     return rpy2_to_pandas(rDF_scalefreetopology)
